# Exergi
This project is a part of the Datadriven Production & Distribution Department 

## Project Intro/Objective
The purpose of this project is to gather all exergi specific code in one repo and share it easily across the organisation. 

## Modules
- **aws.s3**. Module for S3 related functions such as import, export. 
- **aws.rds**. Module used to connect, import and export data from PostgreSQL databases on RDS or local docker environment. 
- **plot**. Common plotting library based on plotly. 

## Installation
A step by step series of examples that tell you how to get a development env running

Say what the step will be

```
pip install exergi
```

To update exergi package please use 

```
pip install --upgrade exergi 
```

## Automated release process

This project utilized gitlab ci for automated release process. For more information see the following link

https://towardsdatascience.com/setup-version-increment-and-automated-release-process-591d87ea1221

## Contributing Members

**Leads : [Kasper Janehag](https://gitlab.stockholmexergi.io/kasper.janehag)**
**Contributor : [Johan Wållgren](https://gitlab.stockholmexergi.io/kasper.janehag)**

## Members:

|Name     |  Role  | 
|---------|-----------------|
|[Kasper Janehag] | Data Scientist        |
|[Johan Wållgren] | Data Scientist         |
